==> wiki3_5_0.zip: wiki3_5_0/plugin/category/CategoryHandler.pm <==
###############################################################################
#
# Categoryץ饰Υϥɥ
#
###############################################################################
package plugin::category::CategoryHandler;
#use strict;
use plugin::category::CategoryCache;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	my $category  = $cgi->param("category");
	my $cachefile = $wiki->config('log_dir')."/category.cache";
	
	if(!(-e $cachefile)){
		&plugin::category::CategoryCache::create_cache($wiki);
	}
	my $result = &Util::load_config_hash(undef,$cachefile);
	
	if($category eq ""){
		$wiki->set_title("ƥΰ");
		my $buf = "";
		foreach my $key (sort(keys(%$result))){
			$buf .= "<h2>".&Util::escapeHTML($key)."</h2>\n<ul>\n";
			my @pages = sort(split(/\t/,$result->{$key}));
			foreach(@pages){
				$buf .= "<li><a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($_)."\">".
				        &Util::escapeHTML($_)."</a></li>\n";
			}
			$buf .= "</ul>\n";
		}
		return $buf;
		
	} else {
		$wiki->set_title("ƥ:".$category);
		my $buf = "<h2>".&Util::escapeHTML($category)."</h2>\n<ul>\n";
		foreach my $pagename (sort(split(/\t/,$result->{$category}))){
			$buf .= "<li><a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($pagename)."\">".
		            &Util::escapeHTML($pagename)."</a></li>\n";
		}
		return $buf."</ul>\n";
	}
}

1;

==> wiki3_5_1.zip: wiki3_5_1/plugin/category/CategoryHandler.pm <==
###############################################################################
#
# Categoryץ饰Υϥɥ
#
###############################################################################
package plugin::category::CategoryHandler;
#use strict;
use plugin::category::CategoryCache;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	my $category  = $cgi->param("category");
	my $cachefile = $wiki->config('log_dir')."/category.cache";
	
	if(!(-e $cachefile)){
		&plugin::category::CategoryCache::create_cache($wiki);
	}
	my $result = &Util::load_config_hash(undef,$cachefile);
	
	if($category eq ""){
		$wiki->set_title("ƥΰ");
		my $buf = "";
		foreach my $key (sort(keys(%$result))){
			$buf .= "<h2>".&Util::escapeHTML($key)."</h2>\n<ul>\n";
			my @pages = sort(split(/\t/,$result->{$key}));
			foreach my $pagename (@pages){
				if($wiki->can_show($pagename)){
					$buf .= "<li><a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($pagename)."\">".
					        &Util::escapeHTML($pagename)."</a></li>\n";
				}
			}
			$buf .= "</ul>\n";
		}
		return $buf;
		
	} else {
		$wiki->set_title("ƥ:".$category);
		my $buf = "<h2>".&Util::escapeHTML($category)."</h2>\n<ul>\n";
		foreach my $pagename (sort(split(/\t/,$result->{$category}))){
			if($wiki->can_show($pagename)){
				$buf .= "<li><a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($pagename)."\">".
			            &Util::escapeHTML($pagename)."</a></li>\n";
			}
		}
		return $buf."</ul>\n";
	}
}

1;
